==> ejc-bfyjerp-impl-3.0.0-20241112.064431-30-sources.jar: com/ejianc/business/project/service/impl/ProjectRegisterServiceImpl.java <==
package com.ejianc.business.project.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.project.mapper.ProjectRegisterMapper;
import com.ejianc.business.project.bean.ProjectRegisterEntity;
import com.ejianc.business.project.service.IProjectRegisterService;

import java.util.List;

/**
 * 项目基本信息管理-项目立项
 * 
 * @author generator
 * 
 */
@Service("projectRegisterService")
public class ProjectRegisterServiceImpl extends BaseServiceImpl<ProjectRegisterMapper, ProjectRegisterEntity> implements IProjectRegisterService{

    @Override
    public ProjectRegisterEntity getByAffirmId(Long affirmId) {
        QueryWrapper<ProjectRegisterEntity> query = new QueryWrapper<>();
        query.eq("affirm_id", affirmId);

        return super.getOne(query);
    }

    @Override
    public List<ProjectRegisterEntity> getAllByOrgIds(List<Long> orgIds, String projectStatus) {
        QueryWrapper<ProjectRegisterEntity> query = new QueryWrapper<>();
        query.in("org_id", orgIds);
        if(StringUtils.isNotBlank(projectStatus)) {
            query.in("status", projectStatus.split(","));
        }

        return super.list(query);
    }

    @Override
    public List<ProjectRegisterEntity> getAllByDepartmentIds(List<Long> departmentIds, String projectStatus) {
        QueryWrapper<ProjectRegisterEntity> query = new QueryWrapper<>();
        query.in("project_department_id", departmentIds);
        if(StringUtils.isNotBlank(projectStatus)) {
            query.in("status", projectStatus.split(","));
        }

        return super.list(query);
    }
}

==> ejc-bfyjerp-impl-3.0.0-20250410.015239-190-sources.jar: com/ejianc/business/project/service/impl/ProjectRegisterServiceImpl.java <==
package com.ejianc.business.project.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.bid.vo.CompanyPerformanceVO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.project.mapper.ProjectRegisterMapper;
import com.ejianc.business.project.bean.ProjectRegisterEntity;
import com.ejianc.business.project.service.IProjectRegisterService;

import java.util.List;
import java.util.Map;

/**
 * 项目基本信息管理-项目立项
 * 
 * @author generator
 * 
 */
@Service("projectRegisterService")
public class ProjectRegisterServiceImpl extends BaseServiceImpl<ProjectRegisterMapper, ProjectRegisterEntity> implements IProjectRegisterService{

    @Autowired
    private ProjectRegisterMapper mapper;

    @Override
    public ProjectRegisterEntity getByAffirmId(Long affirmId) {
        QueryWrapper<ProjectRegisterEntity> query = new QueryWrapper<>();
        query.eq("affirm_id", affirmId);

        return super.getOne(query);
    }

    @Override
    public List<ProjectRegisterEntity> getAllByOrgIds(List<Long> orgIds, String projectStatus) {
        QueryWrapper<ProjectRegisterEntity> query = new QueryWrapper<>();
        query.in("org_id", orgIds);
        if(StringUtils.isNotBlank(projectStatus)) {
            query.in("status", projectStatus.split(","));
        }

        return super.list(query);
    }

    @Override
    public List<ProjectRegisterEntity> getAllByDepartmentIds(List<Long> departmentIds, String projectStatus) {
        QueryWrapper<ProjectRegisterEntity> query = new QueryWrapper<>();
        query.in("project_department_id", departmentIds);
        if(StringUtils.isNotBlank(projectStatus)) {
            query.in("status", projectStatus.split(","));
        }

        return super.list(query);
    }

    @Override
    public List<CompanyPerformanceVO> pagePerformance(Map<String, Object> params) {
        return mapper.pagePerformance(params);
    }

    @Override
    public int countPerformance(Map<String, Object> params) {
        return mapper.countPerformance(params);
    }
}
